@@ -86,8 +86,9 @@ optim_apsim <- function(file, src.dir = ".",
     }
   }
   
-  datami <- data[,-which(names(data) == index), drop = FALSE]
-  if(index == "Date") data$Date <- as.Date(data$Date)
+  ## Index can now potentially reference two columns
+  datami <- data[,-which(names(data) %in% index), drop = FALSE]
+  if(any(grepl("Date", index))) data$Date <- as.Date(data$Date)
   
   ## Setting up weights
   if(missing(weights)){
@@ -183,17 +184,43 @@ optim_apsim <- function(file, src.dir = ".",
     
     if(inherits(sim, "try-error")) return(NA)
     
+    if(!inherits(sim, "data.frame"))
+      stop("the apsim simulation should return an object of class 'data.frame'. \n 
+           Check that the output does simplify to a 'data.frame' instead of a 'list'.")
+    
+    if("outfile" %in% names(sim) && index == "Date")
+      stop("If you have multiple simulations, you should modify the index argument. \n
+           It is possible that 'index = c('outfile', 'Date')' might work.")
+    
     ## Only keep those columns with corresponding names in the data
     ## and only the dates that match those in 'data'
     if(!all(names(data) %in% names(sim))) 
       stop("names in 'data' do not match names in simulation")
     
-    sim.s <- subset(sim, sim$Date %in% data[[index]], select = names(data))
-    
-    if(nrow(sim.s) == 0L) stop("no rows selected in simulations")
+    if(length(index) == 1 && index == "Date"){
+      sim.s <- subset(sim, sim$Date %in% data[[index]], select = names(data))  
+    }else{
+      if(!is.null(data$outfile)) data$outfile <- as.factor(data$outfile)
+      if(!is.null(sim$outfile)) sim$outfile <- as.factor(sim$outfile)
+      sim.s0 <- merge(sim, subset(data, select = index), by = index)  
+      sim.s <- subset(sim.s0, select = names(data))
+    }
+
+    if(nrow(sim.s) != nrow(data)){
+      cat("Number of rows in data", nrow(data), "\n")
+      cat("Number of rows in subset simulation", nrow(sim.s), "\n")
+      stop("Number of rows in data does not equal number of rows in simulation")
+    }
+    if(ncol(sim.s) != ncol(data)){
+      cat("Number of columns in data", ncol(data), "\n")
+      cat("Number of columns in subset simulation", ncol(sim.s), "\n")
+      stop("Number of columns in data does not equal number of columns in simulation")
+    }
+        
+    if(nrow(sim.s) == 0L) stop("Something went wrong. No rows selected in simulations")
     ## Assuming they are aligned, get rid of the 'index' column
-    sim.s <- sim.s[,-which(names(sim.s) == index)]
-    data <- data[,-which(names(data) == index)]
+    sim.s <- sim.s[,-which(names(sim.s) %in% index)]
+    data <- data[,-which(names(data) %in% index)]
     ## Now I need to calculate the residual sum of squares
     ## For this to work all variables should be numeric
     diffs <- as.matrix(data) - as.matrix(sim.s)
